"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const pg_1 = require("pg");
const pg_types_1 = require("pg-types");
const postgres_schema_provider_1 = require("./postgres_schema_provider");
const postgres_data_provider_1 = require("./postgres_data_provider");
const sql_filter_transformer_1 = require("./sql_filter_transformer");
const postgres_operations_1 = require("./postgres_operations");
pg_1.types.setTypeParser(pg_types_1.builtins.NUMERIC, val => parseFloat(val));
exports.default = (cfg, _poolOptions) => {
    const config = {
        host: cfg.host,
        user: cfg.user,
        password: cfg.password,
        database: cfg.db,
        port: cfg.port || 5432,
        max: 10,
        idleTimeoutMillis: 30000,
        connectionTimeoutMillis: 10000,
    };
    const poolOptions = _poolOptions || {};
    if (cfg.cloudSqlConnectionName) {
        config.host = `/cloudsql/${cfg.cloudSqlConnectionName}`;
    }
    const filterParser = new sql_filter_transformer_1.default();
    const pool = new pg_1.Pool(Object.assign(Object.assign({}, config), poolOptions));
    const databaseOperations = new postgres_operations_1.default(pool);
    const dataProvider = new postgres_data_provider_1.default(pool, filterParser);
    const schemaProvider = new postgres_schema_provider_1.default(pool);
    return {
        dataProvider,
        schemaProvider,
        databaseOperations,
        connection: pool,
        cleanup: () => tslib_1.__awaiter(void 0, void 0, void 0, function* () { return pool.end(() => { }); })
    };
};
//# sourceMappingURL=connection_provider.js.map