"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reset = exports.givenIncludeFilterForIdColumn = exports.givenMatchesFilterFor = exports.givenNotFilterQueryFor = exports.givenGreaterThenFilterFor = exports.givenStartsWithFilterFor = exports.givenProjectionExprFor = exports.givenAllFieldsProjectionFor = exports.givenAggregateQueryWith = exports.givenFilterByIdWith = exports.givenOrderByFor = exports.stubEmptyOrderByFor = exports.stubEmptyFilterFor = exports.stubEmptyFilterAndSortFor = exports.filterParser = void 0;
const velo_external_db_commons_1 = require("@wix-velo/velo-external-db-commons");
const jest_when_1 = require("jest-when");
const postgres_utils_1 = require("../../src/postgres_utils");
exports.filterParser = {
    transform: jest.fn(),
    parseFilter: jest.fn(),
    orderBy: jest.fn(),
    parseAggregation: jest.fn(),
    selectFieldsFor: jest.fn(),
};
const stubEmptyFilterAndSortFor = (filter, sort) => {
    (0, exports.stubEmptyFilterFor)(filter);
    (0, exports.stubEmptyOrderByFor)(sort);
};
exports.stubEmptyFilterAndSortFor = stubEmptyFilterAndSortFor;
const stubEmptyFilterFor = (filter) => {
    (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
        .mockReturnValue({ filterExpr: '', parameters: [], offset: 1 });
};
exports.stubEmptyFilterFor = stubEmptyFilterFor;
const stubEmptyOrderByFor = (sort) => {
    (0, jest_when_1.when)(exports.filterParser.orderBy).calledWith(sort)
        .mockReturnValue(velo_external_db_commons_1.EmptySort);
};
exports.stubEmptyOrderByFor = stubEmptyOrderByFor;
const givenOrderByFor = (column, sort) => {
    (0, jest_when_1.when)(exports.filterParser.orderBy).calledWith(sort)
        .mockReturnValue({ sortExpr: `ORDER BY ${(0, postgres_utils_1.escapeIdentifier)(column)} ASC`, sortColumns: [] });
};
exports.givenOrderByFor = givenOrderByFor;
const givenFilterByIdWith = (id, filter) => {
    (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
        .mockReturnValue({ filterExpr: `WHERE ${(0, postgres_utils_1.escapeIdentifier)('_id')} = $1`, parameters: [id], offset: 2 });
};
exports.givenFilterByIdWith = givenFilterByIdWith;
const givenAggregateQueryWith = (having, numericColumns, columnAliases, groupByColumns, filter, offest) => {
    (0, jest_when_1.when)(exports.filterParser.parseAggregation).calledWith({ postFilteringStep: filter, processingStep: having }, offest)
        .mockReturnValue({
        fieldsStatement: `${groupByColumns.map(postgres_utils_1.escapeIdentifier).join(', ')}, MAX(${(0, postgres_utils_1.escapeIdentifier)(numericColumns[0].name)}) AS ${(0, postgres_utils_1.escapeIdentifier)(columnAliases[0])}, SUM(${(0, postgres_utils_1.escapeIdentifier)(numericColumns[1].name)}) AS ${(0, postgres_utils_1.escapeIdentifier)(columnAliases[1])}`,
        groupByColumns,
        offset: offest,
        havingFilter: '',
        parameters: [],
    });
};
exports.givenAggregateQueryWith = givenAggregateQueryWith;
const givenAllFieldsProjectionFor = (projection) => (0, jest_when_1.when)(exports.filterParser.selectFieldsFor).calledWith(projection)
    .mockReturnValue('*');
exports.givenAllFieldsProjectionFor = givenAllFieldsProjectionFor;
const givenProjectionExprFor = (projection) => (0, jest_when_1.when)(exports.filterParser.selectFieldsFor).calledWith(projection)
    .mockReturnValue(projection.map(postgres_utils_1.escapeIdentifier).join(', '));
exports.givenProjectionExprFor = givenProjectionExprFor;
const givenStartsWithFilterFor = (filter, column, value) => (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
    .mockReturnValue({ filterExpr: `WHERE ${(0, postgres_utils_1.escapeIdentifier)(column)} ILIKE $1`, parameters: [`${value}%`], offset: 2 });
exports.givenStartsWithFilterFor = givenStartsWithFilterFor;
const givenGreaterThenFilterFor = (filter, column, value) => (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
    .mockReturnValue({ filterExpr: `WHERE ${(0, postgres_utils_1.escapeIdentifier)(column)} > $1`, parameters: [value], offset: 2 });
exports.givenGreaterThenFilterFor = givenGreaterThenFilterFor;
const givenNotFilterQueryFor = (filter, column, value) => (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
    .mockReturnValue({ filterExpr: `WHERE NOT(${(0, postgres_utils_1.escapeIdentifier)(column)} = $1)`, parameters: [value], offset: 2 });
exports.givenNotFilterQueryFor = givenNotFilterQueryFor;
const givenMatchesFilterFor = (filter, column, value) => (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
    .mockReturnValue({
    filterExpr: `WHERE LOWER(${(0, postgres_utils_1.escapeIdentifier)(column)}) ~ LOWER($1)`,
    parameters: [
        value.split('-').map((v, i, array) => i === array.length - 1 ? v : `${v}[ \t\n-]`)
            .join('')
    ],
    offset: 2
});
exports.givenMatchesFilterFor = givenMatchesFilterFor;
const givenIncludeFilterForIdColumn = (filter, value) => (0, jest_when_1.when)(exports.filterParser.transform).calledWith(filter)
    .mockReturnValue({ filterExpr: `WHERE ${(0, postgres_utils_1.escapeIdentifier)('_id')} IN ($1)`, parameters: [value], offset: 2 });
exports.givenIncludeFilterForIdColumn = givenIncludeFilterForIdColumn;
const reset = () => {
    exports.filterParser.transform.mockClear();
    exports.filterParser.orderBy.mockClear();
    exports.filterParser.parseAggregation.mockClear();
    exports.filterParser.parseFilter.mockClear();
    exports.filterParser.selectFieldsFor.mockClear();
};
exports.reset = reset;
//# sourceMappingURL=sql_filter_transformer_test_support.js.map